Changes
=======

0.2.0
   * More documentation.
0.1.0
   * Added ``RatedDict.ratings`` method to read item ratings values.
0.0.4
   * API refactoring.
0.0.2
   * API refactoring.
0.0.1
   * Pre-Alpha release.
